<?php

namespace Ardent\UtilBundle\EntityBuilder;

use Exception;
use Symfony\Component\Console\Style\SymfonyStyle;

class Builder
{
    /**
     * @var SimpleElement[]
     */
    private array $elements = [];

    public function __construct(
        private readonly SymfonyStyle $io,
    )
    {
    }

    public function add(SimpleElement|string $element): self
    {
        if (is_string($element)) {
            $element = new SimpleElement($element);
        }
        $this->elements[] = $element;

        return $this;
    }

    public function setObject(mixed $object): void
    {
        foreach ($this->elements as $element) {
            $setter = sprintf('set%s', ucfirst($element->getProperty()));
            if (!method_exists($object, $setter)) {
                throw new Exception(sprintf('Object does not have setter "%s"', $setter));
            }
            $object->$setter($this->io->askQuestion($element->getQuestion()));
        }
    }
}